# CsePrivateKeyMetadata

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**kacls_key_metadata** | [**KaclsKeyMetadata**](KaclsKeyMetadata.md) |  | [optional] 
**private_key_metadata_id** | **str** | Output only. The immutable ID for the private key metadata instance. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

